@@ -15,9 +15,10 @@ def cli():
     )
 
     omm_cli.add_argument(
-        "-m", "--models_type",
+        "-m",
+        "--models_type",
         type=str,
-        default='gino',
+        default="gino",
         help="The type of model you want to generate, pass as argument one of the supported: [gino, pydantic]",
     )
 
@@ -43,6 +44,19 @@ def cli():
         default=False,
         help="Create without saving to the file. Only print result to the console.",
     )
+    
+    omm_cli.add_argument(
+        "--no-global-schema",
+        action="store_true",
+        default=False,
+        help="Define schema in table_args, not global in Gino()",
+    )
+    omm_cli.add_argument(
+        "--defaults-off",
+        action="store_true",
+        default=False,
+        help="Do not add defaults in Pydantic & Dataclass models",
+    )
     return omm_cli
 
 
@@ -62,6 +76,7 @@ def main():
         dump=not args.no_dump,
         dump_path=args.target,
         models_type=args.models_type,
+        schema_global=not args.no_global_schema
     )
     print(f"File with result was saved to {target_file} file")
 
